@@ -71,11 +71,13 @@ from .usecases.license_plate_detection import LicensePlateConfig
 from .usecases.pothole_segmentation import PotholeConfig
 from .usecases.wound_segmentation import WoundConfig, WoundSegmentationUseCase
 from .usecases.face_emotion import FaceEmotionConfig
+from .usecases.pipeline_detection import PipelineDetectionUseCase
 from .usecases.parking_space_detection import ParkingSpaceConfig
 from .usecases.underwater_pollution_detection import UnderwaterPlasticConfig
 from .usecases.pedestrian_detection import PedestrianDetectionConfig
 from .usecases.age_detection import AgeDetectionConfig
 from .usecases.mask_detection import MaskDetectionConfig
+from .usecases.pipeline_detection import PipelineDetectionConfig
 from .usecases.chicken_pose_detection import ChickenPoseDetectionConfig
 from .usecases.field_mapping import FieldMappingConfig, FieldMappingUseCase
 from .usecases.leaf_disease import LeafDiseaseDetectionConfig, LeafDiseaseDetectionUseCase
@@ -193,6 +195,7 @@ _underwater_pollution_detection = UnderwaterPlasticUseCase()
 _pedestrian_detection = PedestrianDetectionUseCase()
 _age_detection = AgeDetectionUseCase()
 _mask_detection = MaskDetectionUseCase()
+_pipeline_detection = PipelineDetectionUseCase()
 _banana_defect_detection = BananaMonitoringUseCase()
 _chicken_pose_detection = ChickenPoseDetectionUseCase()
 _theft_detection = TheftDetectionUseCase()
@@ -256,6 +259,7 @@ registry.register_use_case(_age_detection.category, _age_detection.name, AgeDete
 registry.register_use_case(_pricetag_detection.category, _pricetag_detection.name, PriceTagUseCase)
 registry.register_use_case(_weld_defect_detection.category, _weld_defect_detection.name, WeldDefectUseCase  )
 registry.register_use_case(_mask_detection.category, _mask_detection.name, MaskDetectionUseCase)
+registry.register_use_case(_pipeline_detection.category, _pipeline_detection.name, PipelineDetectionUseCase)
 registry.register_use_case(_banana_defect_detection.category, _banana_defect_detection.name, BananaMonitoringUseCase)
 registry.register_use_case(_chicken_pose_detection.category, _chicken_pose_detection.name, ChickenPoseDetectionUseCase)
 registry.register_use_case(_theft_detection.category, _theft_detection.name, TheftDetectionUseCase)
