@@ -415,6 +415,7 @@ class ConfigManager:
             "fire_smoke_detection": None,
             "flare_analysis" : None,
             "mask_detection": None,
+            "pipeline_detection": None,
             "parking_space_detection": None,
             "car_damage_detection":None,
             "weld_defect_detection" : None,
@@ -592,6 +593,7 @@ class ConfigManager:
             return ParkingSpaceConfig
         except ImportError:
             return None
+
     def _get_mask_detection_config_class(self):
         """Register a configuration class for a use case."""
         try:
@@ -600,6 +602,14 @@ class ConfigManager:
         except ImportError:
             return None
 
+    def _get_pipeline_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.pipeline_detection import PipelineDetectionConfig
+            return PipelineDetectionConfig
+        except ImportError:
+            return None
+
     def _get_pothole_segmentation_config_class(self):
         """Register a configuration class for a use case."""
         try:
@@ -972,6 +982,19 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        elif usecase == "pipeline_detection":
+            from ..usecases.pipeline_detection import PipelineDetectionConfig
+
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = PipelineDetectionConfig(
+                category=category or "pipeline_detection",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
         elif usecase == "shoplifting_detection":
             # Import here to avoid circular import
             from ..usecases.shoplifting_detection import ShopliftingDetectionConfig
@@ -1759,6 +1782,11 @@ class ConfigManager:
             from ..usecases.mask_detection import MaskDetectionConfig
             default_config = MaskDetectionConfig()
             return default_config.to_dict()
+        
+        elif usecase == "pipeline_detection":
+            from ..usecases.pipeline_detection import PipelineDetectionConfig
+            default_config = PipelineDetectionConfig()
+            return default_config.to_dict()
 
         elif usecase == "fire_smoke_detection":
             # Import here to avoid circular import
