@@ -51,6 +51,7 @@ from .usecases import (
     ParkingUseCase,
     FaceEmotionUseCase,
     UnderwaterPlasticUseCase,
+    PipelineDetectionUseCase,
     PedestrianDetectionUseCase,
     ChickenPoseDetectionUseCase,
     TheftDetectionUseCase,
@@ -175,6 +176,7 @@ class PostProcessor:
         registry.register_use_case("weld", "weld_defect_detection", WeldDefectUseCase)
         registry.register_use_case("price_tag", "price_tag_detection", PriceTagUseCase)
         registry.register_use_case("mask_detection", "mask_detection", MaskDetectionUseCase)
+        registry.register_use_case("pipeline_detection", "pipeline_detection", PipelineDetectionUseCase)
         registry.register_use_case("automobile", "distracted_driver_detection", DistractedDriverUseCase)
         registry.register_use_case("traffic", "emergency_vehicle_detection", EmergencyVehicleUseCase)
         registry.register_use_case("energy", "solar_panel", SolarPanelUseCase)
